==> dolphin-15.12.1.tar.xz: dolphin-15.12.1/src/settings/kcm/kcmdolphingeneral.h <==
/***************************************************************************
 *   Copyright (C) 2009 by Peter Penz <peter.penz19@gmail.com>             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
 ***************************************************************************/

#ifndef KCMDOLPHINGENERAL_H
#define KCMDOLPHINGENERAL_H

#include <kcmodule.h>
#include <QList>

class SettingsPageBase;

/**
 * @brief Allow to configure general Dolphin settings.
 */
class DolphinGeneralConfigModule : public KCModule
{
    Q_OBJECT

public:
    DolphinGeneralConfigModule(QWidget* parent, const QVariantList& args);
    virtual ~DolphinGeneralConfigModule();

    virtual void save() Q_DECL_OVERRIDE;
    virtual void defaults() Q_DECL_OVERRIDE;

private:
    QList<SettingsPageBase*> m_pages;
};

#endif

==> dolphin_19.12.3.orig.tar.xz: dolphin-19.12.3/src/settings/kcm/kcmdolphingeneral.h <==
/***************************************************************************
 *   Copyright (C) 2009 by Peter Penz <peter.penz19@gmail.com>             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
 ***************************************************************************/

#ifndef KCMDOLPHINGENERAL_H
#define KCMDOLPHINGENERAL_H

#include <kcmodule.h>

#include <QList>

class SettingsPageBase;

/**
 * @brief Allow to configure general Dolphin settings.
 */
class DolphinGeneralConfigModule : public KCModule
{
    Q_OBJECT

public:
    DolphinGeneralConfigModule(QWidget* parent, const QVariantList& args);
    ~DolphinGeneralConfigModule() override;

    void save() override;
    void defaults() override;

private:
    QList<SettingsPageBase*> m_pages;
};

#endif
